# Ping


## Implementations

| Component         | Link                                                                                                                     |
|-------------------|--------------------------------------------------------------------------------------------------------------------------|
| client            | [xpra.client.subsystem.ping](https://github.com/Xpra-org/xpra/blob/master/xpra/client/subsystem/ping.py)         |
| client connection | [xpra.server.source.ping](https://github.com/Xpra-org/xpra/blob/master/xpra/server/source/ping.py)       |
| server            | [xpra.server.subsystem.ping](https://github.com/Xpra-org/xpra/blob/master/xpra/server/subsystem/ping.py) |


## Capabilities


## Network Packets

| Packet Type           | Arguments |
|-----------------------|-----------|
| `ping`                | TBD       |
| `ping-echo`           | TBD       |
